@@ -160,6 +160,7 @@ HistoryView::HistoryView(QWidget *parent) : QTextEdit(parent) {
 	previous_cursor = 0;
 	previous_temporary = 0;
 	last_ans = 0;
+	b_reversed = false;
 #ifdef _WIN32
 	has_lock_symbol = 1;
 #else
@@ -347,8 +348,14 @@ void HistoryView::loadInitial(bool reload) {
 	} else {
 		size_t i = 0;
 		for(; i < settings->v_expression.size() - 1; i++) {
-			if(!settings->v_messages[i].isEmpty()) replaceColors(settings->v_messages[i]);
-			addResult(settings->v_result[i], settings->v_expression[i], settings->v_pexact[i], settings->v_parse[i], true, false, QString(), NULL, 1, i);
+			if(!settings->v_messages[i].isEmpty()) {
+				replaceColors(settings->v_messages[i]);
+				if(reload) {
+					settings->v_messages[i].replace("font-size:normal", "font-size:small ");
+					settings->v_messages[i].replace("width=\"2\"", "width=\"1\"");
+				}
+			}
+			addResult(settings->v_result[i], settings->v_expression[i], settings->v_pexact[i], settings->v_parse[i], true, false, QString(), NULL, reload ? 2 : 1, i);
 		}
 		if((settings->color == 2 && (s_text.contains("color:#00") || s_text.contains("color:#58"))) || (settings->color != 2 && (s_text.contains("color:#FF") || s_text.contains("color:#AA")))) {
 			replaceColors(s_text);
@@ -368,11 +375,15 @@ void HistoryView::loadInitial(bool reload) {
 				settings->v_messages[i].replace("width=\"2\"", "width=\"1\"");
 			}
 		}
-		addResult(settings->v_result[i], settings->v_expression[i], settings->v_pexact[i], settings->v_parse[i], true, false, QString(), NULL, reload && !settings->history_answer.empty() && settings->current_result ? 2 : 1, i);
+		addResult(settings->v_result[i], settings->v_expression[i], settings->v_pexact[i], settings->v_parse[i], true, false, QString(), NULL, reload && !settings->history_answer.empty() && settings->current_result ? 3 : (reload ? 2 : 1), i);
 	}
 	initial_loaded = true;
 	QFontMetrics fm(font());
 	prev_fonti = fm.boundingRect("Öy");
+	if(b_reversed) {
+		previous_cursor = textCursor().position();
+		previous_cursor2 = previous_cursor;
+	}
 }
 
 #define PASTE_H QFontMetrics fm(font()); \
@@ -383,27 +394,29 @@ void HistoryView::clearTemporary() {
 	if(!previous_temporary || previous_html.isEmpty()) return;
 	QTextCursor cur = textCursor();
 	cur.setPosition(previous_cursor);
-	cur.setPosition(0, QTextCursor::KeepAnchor);
+	if(b_reversed) cur.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
+	else cur.setPosition(0, QTextCursor::KeepAnchor);
 	setTextCursor(cur);
 	cur.deleteChar();
 	if(!previous_html2.isEmpty()) {
 		cur.setPosition(previous_cursor2);
-		cur.setPosition(0, QTextCursor::KeepAnchor);
+		if(b_reversed) cur.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
+		else cur.setPosition(0, QTextCursor::KeepAnchor);
 		setTextCursor(cur);
 		cur.deleteChar();
 		insertHtml("<table width=\"100%\">" + previous_html2 + "</table>");
 		previous_html = previous_html2;
-		previous_cursor = textCursor().position();
+		if(!b_reversed) previous_cursor = textCursor().position();
 	} else {
 		previous_html.clear();
-		previous_cursor = 0;
+		if(!b_reversed) previous_cursor = 0;
 	}
 	previous_temporary = false;
 	i_pos = i_pos2;
 	i_pos_p = i_pos_p2;
 	last_ans = last_ans2;
 	last_ref = last_ref2;
-	previous_cursor2 = 0;
+	if(!b_reversed) previous_cursor2 = 0;
 	i_pos2 = 0;
 	i_pos_p2 = 0;
 	previous_html2.clear();
@@ -413,7 +426,7 @@ void HistoryView::clearTemporary() {
 
 bool HistoryView::testTemporaryResultLength(const std::string &str) {
 	QFontMetrics fm(font());
-	return fm.boundingRect(QStringLiteral("#9999") + "= " + unhtmlize(QString::fromStdString(str))).width() < width() * 1.65;
+	return fm.boundingRect(QStringLiteral("#9999") + "= " + unhtmlize(QString::fromStdString(str))).width() + 2 < width() * 1.65;
 }
 
 int HistoryView::maxTemporaryCharacters() {
@@ -430,7 +443,9 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 	}
 	QString serror;
 	bool b_parse_error = (initial_load && !expression.empty() && settings->v_parseerror[index] && !settings->v_messages[index].isEmpty());
+	bool empty_error = false;
 	if(!initial_load && CALCULATOR->message()) {
+		int n = 0, first_error_index = -1;
 		do {
 			if(CALCULATOR->message()->category() == MESSAGE_CATEGORY_IMPLICIT_MULTIPLICATION && (settings->implicit_question_asked || implicit_warning)) {
 				if(!settings->implicit_question_asked) *implicit_warning = true;
@@ -445,11 +460,16 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 				MessageType mtype = CALCULATOR->message()->type();
 				if(temporary) {
 					if(mtype == MESSAGE_ERROR || mtype == MESSAGE_WARNING) {
-						if(!serror.isEmpty()) {
-							if(!serror.startsWith("• ")) serror = "• " + serror;
-							serror += "\n• ";
+						if(CALCULATOR->message()->message().empty()) {
+							empty_error = true;
+						} else {
+							if(n > 0) {
+								if(n == 1) serror = "• " + serror;
+								serror += "\n• ";
+							}
+							serror += mstr;
+							n++;
 						}
-						serror += mstr;
 					}
 				} else {
 					if(mtype == MESSAGE_ERROR || mtype == MESSAGE_WARNING) {
@@ -465,9 +485,12 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 						serror += "";
 						if(CALCULATOR->message()->stage() == MESSAGE_STAGE_PARSING) b_parse_error = true;
 						serror += "\">";
-						if(!mstr.startsWith("-")) serror += "- ";
+						if(n == 0 && (mstr.isEmpty() || mstr[0] != '-')) first_error_index = serror.length();
+						if(n == 1 && first_error_index >= 0) serror.insert(first_error_index, "• ");
+						if(n > 0 && !mstr.startsWith("-")) serror += "• ";
 						serror += mstr.toHtmlEscaped();
 						serror += "</td></tr>";
+						n++;
 					} else {
 						values.insert(values.begin(), std::string("#") + mstr.toStdString());
 					}
@@ -481,7 +504,7 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 	bool comment = false;
 	if(!expression.empty() || !parse.empty()) {
 		comment = !temporary && expression.empty() && parse == "#";
-		if(initial_load && index != settings->v_expression.size() - 1) str += QStringLiteral("<tr><td colspan=\"2\" style=\"padding-bottom: %1 px; padding-top: %3px; border-top: 1px dashed %2; text-align:left").arg(comment ? 0 : paste_h / 4).arg(text_color.name()).arg(paste_h / 2);
+		if((initial_load && index != settings->v_expression.size() - 1) || b_reversed) str += QStringLiteral("<tr><td colspan=\"2\" style=\"padding-bottom: %1 px; padding-top: %3px; border-top: 1px dashed %2; text-align:left").arg(comment ? 0 : paste_h / 4).arg(text_color.name()).arg(paste_h / 2);
 		else str += QStringLiteral("<tr><td colspan=\"2\" style=\"padding-bottom: %1 px; padding-top: 0px; border-top: 0px none %2; text-align:left").arg(comment ? 0 : paste_h / 4).arg(text_color.name());
 		if(comment) str += "; line-height: 1%";
 		str += "\">";
@@ -549,8 +572,12 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 		}
 		if(initial_load && settings->v_protected[index]) {
 			if(has_lock_symbol < 0) {
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+				if(QFontDatabase::families(QFontDatabase::Symbol).contains("Noto Color Emoji")) has_lock_symbol = 1;
+#else
 				QFontDatabase database;
 				if(database.families(QFontDatabase::Symbol).contains("Noto Color Emoji")) has_lock_symbol = 1;
+#endif
 				else has_lock_symbol = 0;
 			}
 			if(has_lock_symbol) str += " <small><sup>🔒</sup></small>";
@@ -558,7 +585,7 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 		}
 		if(temporary) {
 			temporary_error = serror;
-			if(!serror.isEmpty()) str += QStringLiteral("<img src=\"data://img1px.png\" width=\"2\"/><img valign=\"top\" src=\"%1\" height=\"%2\" alt=\"temporary_error\"/>").arg(":/icons/actions/scalable/warning.svg").arg(fm.ascent());
+			if(!serror.isEmpty() || empty_error) str += QStringLiteral("<img src=\"data://img1px.png\" width=\"2\"/><img valign=\"top\" src=\"%1\" height=\"%2\" alt=\"temporary_error\"/>").arg(":/icons/actions/scalable/warning.svg").arg(fm.ascent());
 		}
 		str += "</td></tr>";
 	} else if(!initial_load && !settings->v_result.empty()) {
@@ -576,7 +603,7 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 	str.replace("</i>", "<img src=\"data://img1px.png\" width=\"1\"/></i>");
 	if((!expression.empty() || !parse.empty()) && !temporary) {
 		i_pos = str.length();
-		if(initial_load != 1) i_pos_p = i_pos;
+		if(!initial_load || initial_load > 2) i_pos_p = i_pos;
 	}
 	size_t i_answer_pre = 0;
 	if(temporary && values.empty()) {
@@ -589,22 +616,21 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 		else if(!temporary) i_answer = dual_approx && n == 0 ? settings->history_answer.size() - 1 : settings->history_answer.size();
 		if(!values[i].empty() && values[i][0] == '#') {
 			str += "<tr><td colspan=\"2\" style=\"text-align:left";
-			if(!comment && (initial_load == 1 || (initial_load > 1 && n > 0))) str += "; font-size:small";
+			if(!comment && (initial_load == 1 || initial_load == 2 || (initial_load > 2 && n > 0))) str += "; font-size:small";
 			else if(!comment) str += "; font-size:normal";
 			if((!expression.empty() || !parse.empty()) && i == values.size() - 1) str += QStringLiteral("; padding-bottom: %1 px").arg(paste_h / 4);
 			str += "\">";
 			if(i_answer == 0) str += QStringLiteral("<a name=\"%1:%2\" style=\"text-decoration: none\">").arg(initial_load ? index : settings->v_expression.size() - 1).arg(initial_load ? (int) i : settings->v_result[settings->v_result.size() - 1].size() - i - 1);
-			else str += QStringLiteral("<a name=\"c%1:%2:%3\" style=\"text-decoration: none\">").arg(i_answer).arg(initial_load ? index : settings->v_expression.size() - 1).arg(initial_load == 1 ? (int) i : settings->v_result[settings->v_result.size() - 1].size() - i - 1);
-			if(values[i].size() == 1 || values[i][1] != '-') str += "- ";
+			else str += QStringLiteral("<a name=\"c%1:%2:%3\" style=\"text-decoration: none\">").arg(i_answer).arg(initial_load ? index : settings->v_expression.size() - 1).arg(initial_load == 1 ? (int) i : (initial_load > 1 ? values.size() - i - 1 : settings->v_result[settings->v_result.size() - 1].size() - i - 1));
 			str += QString::fromStdString(values[i]).mid(1);
 			str += "</a></td></tr>";
 			continue;
 		}
 		QFontMetrics fm(font());
-		int w_number = fm.boundingRect("#9999").width();
+		int w_number = fm.boundingRect(i_answer > 9999 ? (i_answer > 99999 ? "#999999" : "#99999") : "#9999").width() + 2;
 		int w = 0;
 		str += "<tr><td valign=\"center\" width=\""; str += QString::number(w_number); str += "\">";
-		if(initial_load != 1) {
+		if(!initial_load || initial_load > 2) {
 			w = fm.boundingRect("= " + unhtmlize(QString::fromStdString(values[i]))).width();
 		}
 		if(i_answer != 0 && i_answer != i_answer_pre) {
@@ -613,9 +639,9 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 			}
 			QString sref;
 			if(settings->color == 2) {
-				sref = QStringLiteral("<a href=\"#%1:%2:%3\" style=\"text-decoration: none; text-align:left; color: #AAAAAA\">#%1</a>").arg(i_answer).arg(initial_load ? (int) index : settings->v_expression.size() - 1).arg(initial_load == 1 ? (int) i : settings->v_result[settings->v_result.size() - 1].size() - i - 1);
+				sref = QStringLiteral("<a href=\"#%1:%2:%3\" style=\"text-decoration: none; text-align:left; color: #AAAAAA\">#%1</a>").arg(i_answer).arg(initial_load ? (int) index : settings->v_expression.size() - 1).arg(initial_load == 1 ? (int) i : (initial_load > 1 ? values.size() - i - 1 : settings->v_result[settings->v_result.size() - 1].size() - i - 1));
 			} else {
-				sref = QStringLiteral("<a href=\"#%1:%2:%3\" style=\"text-decoration: none; text-align:left; color: #585858\">#%1</a>").arg(i_answer).arg(initial_load ? (int) index : settings->v_expression.size() - 1).arg(initial_load == 1 ? (int) i : settings->v_result[settings->v_result.size() - 1].size() - i - 1);
+				sref = QStringLiteral("<a href=\"#%1:%2:%3\" style=\"text-decoration: none; text-align:left; color: #585858\">#%1</a>").arg(i_answer).arg(initial_load ? (int) index : settings->v_expression.size() - 1).arg(initial_load == 1 ? (int) i : (initial_load > 1 ? values.size() - i - 1 : settings->v_result[settings->v_result.size() - 1].size() - i - 1));
 			}
 			bool b = true;
 			if(initial_load) {
@@ -626,13 +652,13 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 				}
 			}
 			if(b) str += sref;
-			if((initial_load > 1 && n == 0) || (!initial_load && (!dual_approx || i == values.size() - 1))) {
+			if((initial_load > 2 && n == 0) || (!initial_load && (!dual_approx || i == values.size() - 1))) {
 				last_ans = i_answer;
 				last_ref = sref;
 			}
 		}
 		str += "</td><td style=\"text-align:right";
-		if(initial_load == 1 || (initial_load > 1 && n > 0 && i_answer <= i_answer_pre) || w * 1.5 + w_number > width() || !settings->format_result) {
+		if(initial_load == 1 || initial_load == 2 || (initial_load > 1 && n > 0 && i_answer <= i_answer_pre) || w * 1.5 + w_number > width() || !settings->format_result) {
 			gsub("</i>", "<img src=\"data://img1px.png\" width=\"1\"/></i>", values[i]);
 		} else if(w * 1.85 + w_number > width()) {
 			str += "; font-size:large";
@@ -655,7 +681,7 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 			str += "<a name=\"TR\" style=\"text-decoration: none\">";
 		} else if(!temporary) {
 			if(i_answer == 0) str += QStringLiteral("<a name=\"%1:%2\" style=\"text-decoration: none\">").arg(initial_load ? index : settings->v_expression.size() - 1).arg(initial_load ? (int) i : settings->v_result[settings->v_result.size() - 1].size() - i - 1);
-			else str += QStringLiteral("<a name=\"p%1:%2:%3\" style=\"text-decoration: none\">").arg(i_answer).arg(initial_load ? index : settings->v_expression.size() - 1).arg(initial_load == 1 ? (int) i : settings->v_result[settings->v_result.size() - 1].size() - i - 1);
+			else str += QStringLiteral("<a name=\"p%1:%2:%3\" style=\"text-decoration: none\">").arg(i_answer).arg(initial_load ? index : settings->v_expression.size() - 1).arg(initial_load == 1 ? (int) i : (initial_load > 1 ? values.size() - i - 1 : settings->v_result[settings->v_result.size() - 1].size() - i - 1));
 		}
 		if(!temporary || !values[i].empty()) {
 			if(b_exact > 0) str += "= ";
@@ -693,6 +719,7 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 		n++;
 	}
 	str.replace("\n", "<br>");
+	str.replace(QChar(0x2028), "<br>");
 	int i = 0;
 	if(!previous_temporary && (!expression.empty() || !parse.empty())) {
 		previous_html2 = previous_html;
@@ -715,7 +742,8 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 		}
 		QTextCursor cur = textCursor();
 		cur.setPosition(previous_cursor);
-		cur.setPosition(0, QTextCursor::KeepAnchor);
+		if(b_reversed) cur.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
+		else cur.setPosition(0, QTextCursor::KeepAnchor);
 		setTextCursor(cur);
 		cur.deleteChar();
 	}
@@ -741,28 +769,35 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 			s_text.insert(i_pos, str);
 		} else {
 			QTextCursor cur = textCursor();
-			cur.setPosition(0);
+			if(b_reversed) cur.movePosition(QTextCursor::End);
+			else cur.setPosition(0);
 			setTextCursor(cur);
-			previous_html.insert(i_pos_p, str);
+			if(b_reversed) previous_html += str;
+			else previous_html.insert(i_pos_p, str);
 			insertHtml("<table width=\"100%\">" + previous_html + "</table>");
-			previous_cursor = textCursor().position();
+			if(!b_reversed) previous_cursor = textCursor().position();
 			previous_html2 = previous_html;
 			i_pos2 = i_pos;
 			i_pos_p2 = i_pos_p;
 			last_ans2 = last_ans;
 			last_ref2 = last_ref;
+			if(b_reversed) moveCursor(QTextCursor::End);
 		}
 	} else {
 		if(initial_load) {
 			if(index == settings->v_expression.size() - 1) {
 				QTextCursor cur = textCursor();
-				cur.setPosition(0);
+				if(b_reversed) cur.movePosition(QTextCursor::End);
+				else cur.setPosition(0);
+				if(b_reversed) previous_cursor = textCursor().position();
 				setTextCursor(cur);
 				insertHtml("<table width=\"100%\">" + str + "</table>");
 				previous_html = str;
-				previous_cursor = textCursor().position();
+				if(!b_reversed) previous_cursor = textCursor().position();
+				if(b_reversed) moveCursor(QTextCursor::End);
 			} else {
-				s_text.insert(0, "<table width=\"100%\">" + str + "</table>");
+				if(b_reversed) s_text += "<table width=\"100%\">" + str + "</table>";
+				else s_text.insert(0, "<table width=\"100%\">" + str + "</table>");
 			}
 		} else {
 			if(previous_html.isEmpty()) {
@@ -774,18 +809,25 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 				}
 				replace_one(previous_html, "border-top: 0px none", "border-top: 1px dashed");
 				replace_one(previous_html, "padding-top: 0px", "padding-top: " + QString::number(paste_h / 2) + "px");
+
 				insertHtml("<table width=\"100%\">" + previous_html + "</table>");
 			}
 			QTextCursor cur = textCursor();
-			cur.setPosition(0);
+			if(b_reversed) cur.movePosition(QTextCursor::End);
+			else cur.setPosition(0);
+			if(b_reversed) previous_cursor = textCursor().position();
 			setTextCursor(cur);
 			insertHtml("<table width=\"100%\">" + str + "</table>");
 			previous_html = str;
-			previous_cursor = textCursor().position();
+			if(!b_reversed) previous_cursor = textCursor().position();
+			if(b_reversed) moveCursor(QTextCursor::End);
 		}
 	}
 	previous_temporary = temporary;
 }
+void HistoryView::setReversed(bool b) {
+	b_reversed = b;
+}
 void HistoryView::changeEvent(QEvent *e) {
 	if(e->type() == QEvent::PaletteChange || e->type() == QEvent::ApplicationPaletteChange) {
 		text_color = palette().text().color();
@@ -828,8 +870,10 @@ void HistoryView::mouseMoveEvent(QMouseEvent *e) {
 					str = str.mid(i, i2 - i);
 					if(str == "temporary_error") str = temporary_error;
 					else str.replace("\\n", "\n");
-					QToolTip::showText(mapToGlobal(e->pos()), str);
-					b_tooltip = true;
+					if(!str.isEmpty()) {
+						QToolTip::showText(mapToGlobal(e->pos()), str);
+						b_tooltip = true;
+					}
 				}
 				break;
 			}
@@ -1087,10 +1131,11 @@ void HistoryView::editComment(int i1, int i2) {
 				std::vector<std::string> values;
 				values.push_back(str.toStdString());
 				addResult(values, "", true, "", settings->v_exact[i1][i2]);
+				emit historyReloaded();
 			} else {
-				settings->v_result[i1].insert(settings->v_result[i1].begin() + i2, str.toStdString());
-				settings->v_exact[i1].insert(settings->v_exact[i1].begin() + i2, settings->v_exact[i1][i2]);
-				settings->v_value[i1].insert(settings->v_value[i1].begin() + i2, settings->v_value[i1][i2]);
+				settings->v_result[i1].insert(settings->v_result[i1].begin(), str.toStdString());
+				settings->v_exact[i1].insert(settings->v_exact[i1].begin(), settings->v_exact[i1][i2]);
+				settings->v_value[i1].insert(settings->v_value[i1].begin(), settings->v_value[i1][i2]);
 				int vpos = verticalScrollBar()->value();
 				reloadHistory();
 				verticalScrollBar()->setValue(vpos);
@@ -1271,10 +1316,10 @@ void HistoryView::setMenuAndToolbarItems(QMenu *mode, QMenu *menu, QAction *acti
 	}
 }
 void HistoryView::doFind() {
-	if(!find(searchEdit->text())) {
+	if(!find(searchEdit->text(), b_reversed ? QTextDocument::FindBackward : QTextDocument::FindFlags())) {
 		QTextCursor c = textCursor();
 		QTextCursor cbak = c;
-		c.movePosition(QTextCursor::Start);
+		c.movePosition(b_reversed ? QTextCursor::End : QTextCursor::Start);
 		setTextCursor(c);
 		if(!find(searchEdit->text())) {
 			setTextCursor(cbak);
