@@ -661,7 +661,7 @@ void KeypadWidget::createNumpad(QWidget *w, int i) {
 	OPERATOR_BUTTON3(settings->multiplicationSign(), "&", "<<", 1, c);
 	button->setToolTip(tr("Multiplication"), tr("Bitwise AND"), tr("Bitwise Shift"));
 	multiplicationButton[i] = button;
-	// Standard calculator button. Do not use more than three characters.
+	//: Standard calculator button. Do not use more than three characters.
 	button = new KeypadButton(tr("DEL"), this, true);
 	connect(button, SIGNAL(clicked()), this, SIGNAL(delClicked()));
 	connect(button, SIGNAL(clicked2()), this, SIGNAL(backspaceClicked()));
@@ -684,7 +684,8 @@ void KeypadWidget::createNumpad(QWidget *w, int i) {
 	divisionButton[i] = button;
 	button->setProperty(BUTTON_DATA, settings->divisionSign(false));
 	button->setToolTip(tr("Division"), tr("Bitwise OR"), tr("Bitwise NOT"));
-	button = new KeypadButton(LOAD_ICON("edit-clear"), this);
+	//: Standard calculator button. Do not use more than three characters.
+	button = new KeypadButton(tr("C"), this);
 	button->setToolTip(tr("Clear expression"));
 	connect(button, SIGNAL(clicked()), this, SIGNAL(clearClicked()));
 	connect(button, SIGNAL(clicked2()), this, SIGNAL(clearClicked()));
@@ -1541,7 +1542,9 @@ void KeypadWidget::defaultAssumptionsActivated() {
 	if(!v || v->isKnown()) return;
 	UnknownVariable *uv = (UnknownVariable*) v;
 	uv->setAssumptions(NULL);
+	settings->assumptions_warning_shown = true;
 	emit expressionCalculationUpdated(0);
+
 }
 void KeypadWidget::assumptionsTypeActivated() {
 	QAction *action = qobject_cast<QAction*>(sender());
@@ -1550,6 +1553,7 @@ void KeypadWidget::assumptionsTypeActivated() {
 	UnknownVariable *uv = (UnknownVariable*) v;
 	if(!uv->assumptions()) uv->setAssumptions(new Assumptions());
 	uv->assumptions()->setType((AssumptionType) action->data().toInt());
+	settings->assumptions_warning_shown = true;
 	emit expressionCalculationUpdated(0);
 }
 void KeypadWidget::assumptionsSignActivated() {
@@ -1559,6 +1563,7 @@ void KeypadWidget::assumptionsSignActivated() {
 	UnknownVariable *uv = (UnknownVariable*) v;
 	if(!uv->assumptions()) uv->setAssumptions(new Assumptions());
 	uv->assumptions()->setSign((AssumptionSign) action->data().toInt());
+	settings->assumptions_warning_shown = true;
 	emit expressionCalculationUpdated(0);
 }
 void KeypadWidget::setKeypadType(int i) {
@@ -1626,10 +1631,6 @@ void KeypadWidget::updateSymbols() {
 }
 void KeypadWidget::changeEvent(QEvent *e) {
 	if(e->type() == QEvent::PaletteChange || e->type() == QEvent::ApplicationPaletteChange) {
-		for(size_t i = 0; i < 2; i++) {
-			if(!acButton[i]) continue;
-			acButton[i]->setIcon(LOAD_ICON("edit-clear"));
-		}
 		if(backButton) backButton->setIcon(LOAD_ICON("go-back"));
 		if(forwardButton) forwardButton->setIcon(LOAD_ICON("go-forward"));
 		if(customEditButton) customEditButton->setIcon(LOAD_ICON("document-edit"));
