@@ -59,7 +59,7 @@ int main(int argc, char **argv) {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0))
 	app.setDesktopFileName("io.github.Qalculate.qalculate-qt");
 #endif
-	app.setApplicationVersion("5.7.0");
+	app.setApplicationVersion("5.8.0");
 #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 	app.setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
@@ -100,9 +100,9 @@ int main(int argc, char **argv) {
 		}
 #else
 			QString lang = settings->custom_lang;
-			if(lang.indexOf(".") < 0) lang += ".utf8";
 			setenv("LANGUAGE", lang.toLocal8Bit().data(), 1);
-			setenv("LC_MESSAGES", lang.toLocal8Bit().data(), 1);
+			if(lang.indexOf(".") < 0 && lang.indexOf("_") > 0) lang += ".utf8";
+			if(lang.indexOf(".") > 0) setenv("LC_MESSAGES", lang.toLocal8Bit().data(), 1);
 		}
 #endif
 #ifndef TRANSLATIONS_DIR
@@ -129,6 +129,16 @@ int main(int argc, char **argv) {
 	parser->addOption(vOption);
 	QCommandLineOption wOption(QStringList() << "w" << "workspace", QApplication::tr("Open workspace"), QApplication::tr("FILE"));
 	parser->addOption(wOption);
+	QCommandLineOption testOption(QStringList() << "run-test");
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 8, 0))
+	testOption.setFlags(QCommandLineOption::HiddenFromHelp);
+#endif
+	parser->addOption(testOption);
+	QCommandLineOption stopTestOption(QStringList() << "stop-test");
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 8, 0))
+	stopTestOption.setFlags(QCommandLineOption::HiddenFromHelp);
+#endif
+	parser->addOption(stopTestOption);
 	parser->addPositionalArgument("expression", QApplication::tr("Expression to calculate"), QApplication::tr("[EXPRESSION]"));
 	parser->addHelpOption();
 	parser->process(app);
@@ -175,6 +185,10 @@ int main(int argc, char **argv) {
 					} else if(!parser->value(wOption).isEmpty()) {
 						command = "w";
 						command += parser->value(wOption);
+					} else if(parser->isSet(testOption)) {
+						command = "t";
+					} else if(parser->isSet(stopTestOption)) {
+						command = "e";
 					} else if(ami_changed) {
 						command = "-";
 					} else {
