@@ -131,6 +131,8 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 		box2->setChecked(settings->preserve_history_height > 0);
 	}
 	box2->setToolTip(tr("Do not change the height of history list when keypad or number bases are show or hidden."));
+	BOX(tr("Place expression field below history (experimental)"), settings->expression_pos == 1, expressionPositionToggled(bool));
+	BOX(tr("Show status bar"), settings->show_statusbar, showStatusBarToggled(bool));
 	l->addWidget(new QLabel(tr("Window title:"), this), r, 0);
 	combo = new QComboBox(this);
 	combo->addItem(tr("Application name"), TITLE_APP);
@@ -170,7 +172,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	BOX(tr("Disable cursor blinking"), settings->disable_cursor_blinking, disableCursorBlinkingToggled(bool));
 	BOX(tr("Colorize result"), settings->colorize_result, colorizeToggled(bool));
 	BOX(tr("Format result"), settings->format_result, formatToggled(bool));
-	BOX1(tr("Custom result font:"), settings->use_custom_result_font, resultFontToggled(bool));
+	BOX1(tr("Custom history font:"), settings->use_custom_result_font, resultFontToggled(bool));
 	QPushButton *button = new QPushButton(font_string(settings->custom_result_font), this); l->addWidget(button, r, 1); button->setEnabled(box->isChecked());; r++;
 	connect(button, SIGNAL(clicked()), this, SLOT(resultFontClicked())); connect(box, SIGNAL(toggled(bool)), button, SLOT(setEnabled(bool)));
 	BOX1(tr("Custom expression font:"), settings->use_custom_expression_font, expressionFontToggled(bool));
@@ -287,7 +289,19 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	l->addLayout(l2, r, 0, 1, 2); r++;
 	BOX(tr("Use lower case letters in non-decimal numbers"), settings->printops.lower_case_numbers, lowerCaseToggled(bool));
 	BOX(tr("Use special duodecimal symbols"), settings->printops.duodecimal_symbols, duodecimalSymbolsToggled(bool));
-	BOX(tr("Use dot as multiplication sign"), settings->printops.multiplication_sign != MULTIPLICATION_SIGN_X, multiplicationDotToggled(bool));
+	l->addWidget(new QLabel(tr("Multiplication sign:"), this), r, 0);
+	combo = new QComboBox(this);
+	//: Unicode character name
+	combo->addItem(QString(" × (%1)").arg(tr("multiplication sign")), MULTIPLICATION_SIGN_X);
+	//: Unicode character name
+	combo->addItem(QString(" ⋅ (%1)").arg(tr("dot operator")), MULTIPLICATION_SIGN_DOT);
+	//: Unicode character name
+	combo->addItem(QString(" · (%1)").arg(tr("middle dot")), MULTIPLICATION_SIGN_ALTDOT);
+	//: Unicode character name
+	combo->addItem(QString(" * (%1)").arg(tr("asterisk")), MULTIPLICATION_SIGN_ASTERISK);
+	combo->setCurrentIndex(combo->findData(settings->printops.multiplication_sign));
+	connect(combo, SIGNAL(currentIndexChanged(int)), this, SLOT(multiplicationSignChanged(int)));
+	l->addWidget(combo, r, 1); r++;
 	BOX(tr("Use Unicode division slash in output"), settings->printops.division_sign == DIVISION_SIGN_DIVISION_SLASH, divisionSlashToggled(bool));
 	BOX(tr("Spell out logical operators"), settings->printops.spell_out_logical_operators, spellOutToggled(bool));
 	BOX(tr("Use E-notation instead of 10^n"), settings->printops.exp_display != EXP_POWER_OF_10, eToggled(bool));
@@ -316,7 +330,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	combo->setCurrentIndex(combo->findData(settings->printops.digit_grouping));
 	connect(combo, SIGNAL(currentIndexChanged(int)), this, SLOT(groupingChanged(int)));
 	l->addWidget(combo, r, 1); r++;
-	BOX(tr("Automatically group digits in input (experimental)"), settings->automatic_digit_grouping, automaticDigitGroupingToggled(bool));
+	BOX(tr("Automatically group digits in input"), settings->automatic_digit_grouping, automaticDigitGroupingToggled(bool));
 	l->addWidget(new QLabel(tr("Interval display:"), this), r, 0);
 	combo = new QComboBox(this);
 	combo->addItem(tr("Adaptive"), -1);
@@ -455,7 +469,7 @@ void PreferencesDialog::langChanged(int i) {
 		case 7: {settings->custom_lang = "nl_NL"; break;}
 		case 8: {settings->custom_lang = "pt_PT"; break;}
 		case 9: {settings->custom_lang = "pt_BR"; break;}
-		case 10: {settings->custom_lang = "ru"; break;}
+		case 10: {settings->custom_lang = "ru_RU"; break;}
 		case 11: {settings->custom_lang = "sl_SL"; break;}
 		case 12: {settings->custom_lang = "sv_SE"; break;}
 		case 13: {settings->custom_lang = "zh_CN"; break;}
@@ -482,6 +496,14 @@ void PreferencesDialog::preserveHeightChanged(int state) {
 	settings->keypad_appended = false;
 	settings->bases_appended = false;
 }
+void PreferencesDialog::expressionPositionToggled(bool b) {
+	settings->expression_pos = (b ? 1 : 0);
+	emit expressionPositionChanged();
+}
+void PreferencesDialog::showStatusBarToggled(bool b) {
+	settings->show_statusbar = b;
+	emit showStatusBarChanged();
+}
 void PreferencesDialog::keepAboveToggled(bool b) {
 	settings->always_on_top = b;
 	if(settings->always_on_top) setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
@@ -545,15 +567,17 @@ void PreferencesDialog::duodecimalSymbolsToggled(bool b) {
 	settings->printops.duodecimal_symbols = b;
 	emit resultDisplayUpdated();
 }
-void PreferencesDialog::multiplicationDotToggled(bool b) {
-	if(b) settings->printops.multiplication_sign = MULTIPLICATION_SIGN_ALTDOT;
-	else settings->printops.multiplication_sign = MULTIPLICATION_SIGN_X;
+void PreferencesDialog::multiplicationSignChanged(int i) {
+	settings->printops.multiplication_sign = (MultiplicationSign) qobject_cast<QComboBox*>(sender())->itemData(i).toInt();
 	emit resultDisplayUpdated();
 	emit symbolsUpdated();
 }
 void PreferencesDialog::divisionSlashToggled(bool b) {
-	if(b) settings->printops.division_sign = DIVISION_SIGN_DIVISION_SLASH;
-	else settings->printops.division_sign = DIVISION_SIGN_SLASH;
+	if(b) {
+		settings->printops.division_sign = DIVISION_SIGN_DIVISION_SLASH;
+	} else {
+		settings->printops.division_sign = DIVISION_SIGN_SLASH;
+	}
 	emit resultDisplayUpdated();
 	emit symbolsUpdated();
 }
@@ -562,8 +586,11 @@ void PreferencesDialog::spellOutToggled(bool b) {
 	emit resultDisplayUpdated();
 }
 void PreferencesDialog::eToggled(bool b) {
-	if(b) settings->printops.exp_display = EXP_LOWERCASE_E;
-	else settings->printops.exp_display = EXP_POWER_OF_10;
+	if(b) {
+		settings->printops.exp_display = EXP_LOWERCASE_E;
+	} else {
+		settings->printops.exp_display = EXP_POWER_OF_10;
+	}
 	emit resultDisplayUpdated();
 }
 void PreferencesDialog::imaginaryJToggled(bool b) {
@@ -664,8 +691,11 @@ void PreferencesDialog::simplifiedPercentageToggled(bool b) {
 	emit expressionFormatUpdated(true);
 }
 void PreferencesDialog::readPrecisionToggled(bool b) {
-	if(b) settings->evalops.parse_options.read_precision = READ_PRECISION_WHEN_DECIMALS;
-	else settings->evalops.parse_options.read_precision = DONT_READ_PRECISION;
+	if(b) {
+		settings->evalops.parse_options.read_precision = READ_PRECISION_WHEN_DECIMALS;
+	} else {
+		settings->evalops.parse_options.read_precision = DONT_READ_PRECISION;
+	}
 	emit expressionFormatUpdated(true);
 }
 void PreferencesDialog::rpnKeysToggled(bool b) {
@@ -713,6 +743,7 @@ void PreferencesDialog::caretAsXorToggled(bool b) {
 }
 void PreferencesDialog::automaticDigitGroupingToggled(bool b) {
 	settings->automatic_digit_grouping = b;
+	emit automaticDigitGroupingChanged();
 }
 void PreferencesDialog::closeWithEscToggled(bool b) {
 	settings->close_with_esc = b;
@@ -723,8 +754,11 @@ void PreferencesDialog::disableCursorBlinkingToggled(bool b) {
 	else qApp->setCursorFlashTime(1000);
 }
 void PreferencesDialog::mixedUnitsToggled(bool b) {
-	if(b) settings->evalops.mixed_units_conversion = MIXED_UNITS_CONVERSION_DEFAULT;
-	else settings->evalops.mixed_units_conversion = MIXED_UNITS_CONVERSION_NONE;
+	if(b) {
+		settings->evalops.mixed_units_conversion = MIXED_UNITS_CONVERSION_DEFAULT;
+	} else {
+		settings->evalops.mixed_units_conversion = MIXED_UNITS_CONVERSION_NONE;
+	}
 	emit expressionCalculationUpdated(0);
 }
 void PreferencesDialog::conversionChanged(int i) {
@@ -921,8 +955,11 @@ void PreferencesDialog::styleChanged(int i) {
 	settings->updateStyle();
 }
 void PreferencesDialog::factorizeToggled(bool b) {
-	if(b) settings->evalops.structuring = STRUCTURING_FACTORIZE;
-	else settings->evalops.structuring = STRUCTURING_EXPAND;
+	if(b) {
+		settings->evalops.structuring = STRUCTURING_FACTORIZE;
+	} else {
+		settings->evalops.structuring = STRUCTURING_EXPAND;
+	}
 	emit expressionCalculationUpdated(0);
 }
 void PreferencesDialog::closeEvent(QCloseEvent *e) {
