@@ -51,7 +51,7 @@ class PreferencesDialog : public QDialog {
 		void bitsChanged(int);
 		void lowerCaseToggled(bool);
 		void duodecimalSymbolsToggled(bool);
-		void multiplicationDotToggled(bool);
+		void multiplicationSignChanged(int);
 		void divisionSlashToggled(bool);
 		void spellOutToggled(bool);
 		void eToggled(bool);
@@ -112,6 +112,8 @@ class PreferencesDialog : public QDialog {
 		void closeWithEscToggled(bool);
 		void disableCursorBlinkingToggled(bool);
 		void showPercentInNumpadToggled(bool);
+		void expressionPositionToggled(bool);
+		void showStatusBarToggled(bool);
 
 	public:
 
@@ -146,6 +148,9 @@ class PreferencesDialog : public QDialog {
 		void binaryBitsChanged();
 		void statusModeChanged();
 		void buttonLocationChanged();
+		void automaticDigitGroupingChanged();
+		void expressionPositionChanged();
+		void showStatusBarChanged();
 		void dialogClosed();
 
 };
