@@ -66,6 +66,7 @@ class QalculateWindow : public QMainWindow {
 
 		void setCommandLineParser(QCommandLineParser*);
 		bool displayMessages();
+		void updateWindowTitleResult(const std::string &str);
 		bool updateWindowTitle(const QString &str = QString(), bool is_result = false, bool type_change = false);
 		void executeFromFile(const QString&);
 		void initFinished();
@@ -81,7 +82,7 @@ class QalculateWindow : public QMainWindow {
 		ExpressionEdit *expressionEdit;
 		HistoryView *historyView;
 		QSplitter *ehSplitter;
-		QLabel *statusLabel, *statusIconLabel;
+		QLabel *statusLabel;
 		PreferencesDialog *preferencesDialog;
 		DataSetsDialog *datasetsDialog;
 		FunctionsDialog *functionsDialog;
@@ -112,7 +113,9 @@ class QalculateWindow : public QMainWindow {
 		QAction *firstFunctionsMenuOptionAction, *firstVariablesMenuOptionAction, *firstUnitsMenuOptionAction;
 		QList<QAction*> recentWSAction, recentVariableActions, favouriteVariableActions, recentFunctionActions, favouriteFunctionActions, recentUnitActions, favouriteUnitActions;
 		QSpinBox *customOutputBaseEdit, *customInputBaseEdit, *minDecimalsEdit, *maxDecimalsEdit;
-		QTimer *ecTimer, *rfTimer, *autoCalculateTimer, *decimalsTimer, *resizeTimer, *emhTimer;
+		QTimer *ecTimer, *rfTimer, *autoCalculateTimer, *decimalsTimer, *resizeTimer, *emhTimer, *testTimer;
+		qint64 prev_test_time;
+		int prev_test_type;
 
 		QTableWidget *rpnView;
 		QAction *rpnUpAction, *rpnDownAction, *rpnSwapAction, *rpnCopyAction, *rpnLastxAction, *rpnDeleteAction, *rpnClearAction;
@@ -125,11 +128,12 @@ class QalculateWindow : public QMainWindow {
 		void setResult(Prefix *prefix = NULL, bool update_history = true, bool update_parse = false, bool force = false, std::string transformation = "", bool do_stack = false, size_t stack_index = 0, bool register_moved = false, bool supress_dialog = false, bool calculate_selection = false);
 		void executeCommand(int command_type, bool show_result = true, std::string ceu_str = "", Unit *u = NULL, int run = 1);
 		void changeEvent(QEvent *e) override;
-		bool askTC(MathStructure&);
-		bool askSinc(MathStructure&);
-		bool askDot(const std::string&);
+		bool warnAssumptions(MathStructure&, bool = false);
+		bool askTC(MathStructure&, bool = false);
+		bool askSinc(MathStructure&, bool = false);
+		bool askDot(const std::string&, bool = false);
 		bool askImplicit();
-		bool askPercent();
+		bool askPercent(bool = false);
 		void keyPressEvent(QKeyEvent*) override;
 		bool eventFilter(QObject*, QEvent*) override;
 		void closeEvent(QCloseEvent*) override;
@@ -150,9 +154,11 @@ class QalculateWindow : public QMainWindow {
 		void beforeShowDock(QDockWidget*, bool);
 		void afterShowDock(QDockWidget*);
 		void updateInsertFunctionDialogs();
+		void updateStatusText();
 
 	protected slots:
 
+		void testTimeout();
 		void updateBinEditSize(QFont* = NULL);
 		void onBinaryBitsChanged();
 		void onSymbolClicked(const QString&);
@@ -312,6 +318,8 @@ class QalculateWindow : public QMainWindow {
 		void resultBasesLinkActivated(const QString&);
 		void showBasesContextMenu(const QPoint&);
 		void copyBases();
+		void onExpressionPositionChanged();
+		void onShowStatusBarChanged();
 
 	public slots:
 
@@ -360,6 +368,7 @@ class QalculateWindow : public QMainWindow {
 		void reportBug();
 		void help();
 		void loadInitialHistory();
+		void startTest();
 
 	signals:
 
@@ -393,7 +402,7 @@ class MathSpinBox : public QSpinBox {
 
 		int valueFromText(const QString &text) const override;
 		QValidator::State validate(QString &text, int &pos) const override;
-		void keyPressEvent(QKeyEvent *event);
+		void keyPressEvent(QKeyEvent *event) override;
 
 	signals:
 
